import { Store } from 'ferda/../store'

import { LATEST_ROUND_INFO_VISIBILITY, OLDER_ROUND_INFO_VISIBILITY } from 'ferda_auction_js/constants'

export const AuctionDetailModule = {
    namespaced: true,
    getters: {
        /**
         * Based on the state of this round and whether it's the latest one, returns true if the given information
         * should be displayed, and false if not.
         *
         * @returns { Boolean } The visibility information for the specified round state
         */
        is_displayed: () =>
            (is_latest, round_state, info_name) => {
                const table = is_latest ?
                    LATEST_ROUND_INFO_VISIBILITY : OLDER_ROUND_INFO_VISIBILITY
                return table[round_state][info_name]
            },
        /**
         * Returns the state of this round based on its status. (Status and state are often different strings.)
         *
         * @returns { String } The state of the specified round.
         */
        get_state: () => ({ status, auction_winner }) => {
            if (status === 'pending_payment') {
                return auction_winner.status === 'pending_payment' ?
                    'PENDING_PAYMENT' : 'PENDING_PENALTY'
            }
            return String(status).toUpperCase()
        },
    },
}

export const AuctionSettingsModule = {
    namespaced: true,
    state: {
        AUCTION_BASE_URL: null,
    },
    mutations: {
        set_auction_base_url(state, value) { state.AUCTION_BASE_URL = value },
    },
    getters: {
        AUCTION_BASE_URL: state => state.AUCTION_BASE_URL,
    },
}

export const PluginStore = {
    modules: {
        ...Store.modules,
        auction_detail: AuctionDetailModule,
        auction_settings: AuctionSettingsModule,
    },
}
